Description = "Новый перекресток";
CreationDate = "14.12.2010 10:50";
Version = "1.5.0.0 Beta";
AllRedTime = 3;
SeasonTime = "Включен";
IsCalcTimes = false;
IsExtYearPlan = false;
ASSUDSystem = "Комсигнал (АСУДД-КС)";
SystemID = 1;
ASUDDFilter = "Включен";
BittDU = "Нет";
ModelList[3] = new Model('КДУ-3.2Н (24 вых.)');
with (ModelList[3]) {
	Outputs[0] = new ModelOutput(0);
	Outputs[1] = new ModelOutput(1);
	Outputs[2] = new ModelOutput(2);
	Outputs[3] = new ModelOutput(0);
	Outputs[4] = new ModelOutput(1);
	Outputs[5] = new ModelOutput(2);
	Outputs[6] = new ModelOutput(0);
	Outputs[7] = new ModelOutput(1);
	Outputs[8] = new ModelOutput(2);
	Outputs[9] = new ModelOutput(0);
	Outputs[10] = new ModelOutput(1);
	Outputs[11] = new ModelOutput(2);
	Outputs[12] = new ModelOutput(0);
	Outputs[13] = new ModelOutput(1);
	Outputs[14] = new ModelOutput(2);
	Outputs[15] = new ModelOutput(0);
	Outputs[16] = new ModelOutput(1);
	Outputs[17] = new ModelOutput(2);
	Outputs[18] = new ModelOutput(0);
	Outputs[19] = new ModelOutput(1);
	Outputs[20] = new ModelOutput(2);
	Outputs[21] = new ModelOutput(0);
	Outputs[22] = new ModelOutput(1);
	Outputs[23] = new ModelOutput(2);
}
ControllerList[0] = new Controller(3,1);
with (ControllerList[0]){
	Outputs[0] = new ControllerOutput(0, 0);
	Outputs[1] = new ControllerOutput(0, 1);
	Outputs[2] = new ControllerOutput(0, 2);
	Outputs[3] = new ControllerOutput(1, 0);
	Outputs[4] = new ControllerOutput(1, 1);
	Outputs[5] = new ControllerOutput(1, 2);
	Outputs[6] = new ControllerOutput(2, 0);
	Outputs[7] = new ControllerOutput(2, 1);
	Outputs[8] = new ControllerOutput(2, 2);
	Outputs[9] = new ControllerOutput(3, 0);
	Outputs[10] = new ControllerOutput(3, 1);
	Outputs[11] = new ControllerOutput(3, 2);
	Outputs[12] = new ControllerOutput(4, 0);
	Outputs[13] = new ControllerOutput(4, 1);
	Outputs[14] = new ControllerOutput(4, 2);
	Outputs[15] = new ControllerOutput(5, 0);
	Outputs[16] = new ControllerOutput(8, 0);
	Outputs[17] = new ControllerOutput(5, 2);
	Outputs[18] = new ControllerOutput(6, 0);
	Outputs[19] = new ControllerOutput(8, 2);
	Outputs[20] = new ControllerOutput(6, 2);
	Outputs[21] = new ControllerOutput(7, 0);
	Outputs[22] = new ControllerOutput(9, 2);
	Outputs[23] = new ControllerOutput(7, 2);
}
TrendGroupList[0] = new TrendGroup(0);
with (TrendGroupList[0]){
	Trends[0] = new Trend(0, 1, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 0);
		Outputs[1] = new TrendOutput(0, 1);
		Outputs[2] = new TrendOutput(0, 2);
		Times[2] = 12;
		Times[3] = 9;
		Times[4] = 6;
		Times[7] = 1;
	}
}
TrendGroupList[1] = new TrendGroup(0);
with (TrendGroupList[1]){
	Trends[0] = new Trend(0, 1, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 3);
		Outputs[1] = new TrendOutput(0, 4);
		Outputs[2] = new TrendOutput(0, 5);
		Times[2] = 9;
		Times[3] = 6;
		Times[4] = 3;
		Times[7] = 5;
		Times[8] = 4;
	}
}
TrendGroupList[2] = new TrendGroup(0);
with (TrendGroupList[2]){
	Trends[0] = new Trend(0, 1, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 6);
		Outputs[1] = new TrendOutput(0, 7);
		Outputs[2] = new TrendOutput(0, 8);
		Times[2] = 12;
		Times[3] = 9;
		Times[4] = 6;
		Times[7] = 1;
	}
}
TrendGroupList[3] = new TrendGroup(0);
with (TrendGroupList[3]){
	Trends[0] = new Trend(0, 1, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 9);
		Outputs[1] = new TrendOutput(0, 10);
		Outputs[2] = new TrendOutput(0, 11);
		Times[2] = 18;
		Times[3] = 15;
		Times[4] = 12;
		Times[7] = 1;
	}
}
TrendGroupList[4] = new TrendGroup(0);
with (TrendGroupList[4]){
	Trends[0] = new Trend(0, 1, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 12);
		Outputs[1] = new TrendOutput(0, 13);
		Outputs[2] = new TrendOutput(0, 14);
		Times[2] = 9;
		Times[3] = 6;
		Times[4] = 3;
		Times[7] = 9;
		Times[8] = 8;
	}
}
TrendGroupList[5] = new TrendGroup(1);
with (TrendGroupList[5]){
	Trends[0] = new Trend(1, 0, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 15);
		Outputs[2] = new TrendOutput(0, 17);
		Times[2] = 16;
		Times[4] = 13;
	}
}
TrendGroupList[6] = new TrendGroup(1);
with (TrendGroupList[6]){
	Trends[0] = new Trend(1, 0, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 18);
		Outputs[2] = new TrendOutput(0, 20);
		Times[2] = 7;
		Times[4] = 4;
		Times[8] = 4;
	}
}
TrendGroupList[7] = new TrendGroup(1);
with (TrendGroupList[7]){
	Trends[0] = new Trend(1, 0, 1);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 21);
		Outputs[2] = new TrendOutput(0, 23);
		Times[2] = 7;
		Times[4] = 4;
		Times[8] = 4;
	}
}
TrendGroupList[8] = new TrendGroup(1);
with (TrendGroupList[8]){
	Trends[0] = new Trend(1, 0, 0);
	with (Trends[0]){
		Outputs[0] = new TrendOutput(0, 16);
		Outputs[2] = new TrendOutput(0, 19);
		Times[2] = 17;
		Times[4] = 14;
	}
}
TrendGroupList[9] = new TrendGroup(3);
with (TrendGroupList[9]){
	Trends[0] = new Trend(3, 0, 0);
	with (Trends[0]){
		Outputs[2] = new TrendOutput(0, 22);
	}
}
WorkPhaseList[0] = new Phase(1);
with (WorkPhaseList[0]){
	Cycles[0] = 12;
}
WorkPhaseList[1] = new Phase(2);
with (WorkPhaseList[1]){
	Cycles[0] = 14;
}
with (WorkPhaseList[0]){
	Cycles[0] = 12;
}
with (WorkPhaseList[1]){
	Cycles[0] = 14;
}
Call1PhaseList[0] = new Phase(2);
Call1PhaseList[1] = new Phase(1);
Call2PhaseList[0] = new Phase(2);
Call2PhaseList[1] = new Phase(1);
step0_0 = new Step(1,0,12,10,'Ф1');
step0_0.TrendStates = [0,5,0,0,5,0,5,5,0,0];
step0_1 = new Step(-1,1,1,1,'>>');
step0_1.TrendStates = [0,5,0,2,5,0,5,5,0,0];
step0_2 = new Step(-1,2,1,1,'>>');
step0_2.TrendStates = [0,5,0,2,5,0,5,5,2,0];
step0_3 = new Step(-1,3,1,1,'>>');
step0_3.TrendStates = [0,5,0,2,5,2,5,5,2,0];
step0_4 = new Step(-1,4,1,1,'>>');
step0_4.TrendStates = [0,5,0,3,5,2,5,5,2,0];
step0_5 = new Step(-1,5,1,1,'>>');
step0_5.TrendStates = [0,5,0,3,5,2,5,5,4,0];
step0_6 = new Step(-1,6,1,1,'>>');
step0_6.TrendStates = [0,5,0,3,5,4,5,5,4,0];
step0_7 = new Step(-1,7,3,3,'>>');
step0_7.TrendStates = [2,5,2,4,5,4,5,5,4,0];
step0_8 = new Step(-1,8,1,1,'>>');
step0_8.TrendStates = [3,5,3,4,7,4,5,5,4,0];
step0_9 = new Step(-1,9,2,2,'>>');
step0_9.TrendStates = [3,5,3,4,8,4,5,5,4,0];
step0_10 = new Step(-1,10,1,1,'>>');
step0_10.TrendStates = [4,5,4,4,8,4,5,5,4,0];
step0_11 = new Step(-1,11,1,1,'>>');
step0_11.TrendStates = [4,7,4,4,8,4,5,5,4,0];
step0_12 = new Step(-1,12,4,4,'>>');
step0_12.TrendStates = [4,8,4,4,8,4,8,8,4,0];
step0_13 = new Step(2,13,14,12,'Ф2');
step0_13.TrendStates = [5,0,5,5,0,5,0,0,5,0];
step0_14 = new Step(-1,14,2,2,'>>');
step0_14.TrendStates = [5,2,5,5,2,5,0,0,5,0];
step0_15 = new Step(-1,15,1,1,'>>');
step0_15.TrendStates = [5,2,5,5,2,5,2,2,5,0];
step0_16 = new Step(-1,16,2,2,'>>');
step0_16.TrendStates = [5,3,5,5,3,5,2,2,5,0];
step0_17 = new Step(-1,17,1,1,'>>');
step0_17.TrendStates = [5,3,5,5,3,5,4,4,5,0];
step0_18 = new Step(-1,18,2,2,'>>');
step0_18.TrendStates = [5,4,5,5,4,5,4,4,5,0];
step0_19 = new Step(-1,19,1,1,'>>');
step0_19.TrendStates = [7,4,7,7,4,5,4,4,5,0];
WorkProgs[0] = new Program(53,49,'Новый цикл № 1',0);
WorkProgs[0].Steps = [step0_0,step0_1,step0_2,step0_3,step0_4,step0_5,step0_6,step0_7,step0_8,step0_9,step0_10,step0_11,step0_12,step0_13,step0_14,step0_15,step0_16,step0_17,step0_18,step0_19];
DayPlanList[0] = new DayPlan('Суточный план № 1');
with (DayPlanList[0]){
	Items[0] = new DayPlanItem('00:00', -1);
	Items[1] = new DayPlanItem('05:00', 0);
}
WeekPlanList[0] = new WeekPlan('Недельный план № 1');
with (WeekPlanList[0]){
	Items[0] = new WeekPlanItem(0, 0);
}
YearPlan[0] = new YearPlanItem('01 января', 0);
Alg1param1 = new AlgParam('T<sub>экипажное</sub>','4 с');
Algorithm_0 = new AdaptiveAlgorithm(0,'Поиск разрывов',[Alg1param1],[]);
Alg2param1 = new AlgParam('T<sub>экипажное</sub>','4 с');
Algorithm_1 = new AdaptiveAlgorithm(1,'Поиск разрывов с сохранением времени цикла',[Alg2param1],[]);
Alg3param1 = new AlgParam('Задержка вызова','0 с');
Algorithm_2 = new AdaptiveAlgorithm(2,'Вызов ТВП или фазы',[Alg3param1],[]);
AdaptiveAlgs = new AdaptiveAlgorithms([Algorithm_0,Algorithm_1,Algorithm_2],false,false,true);
